===
API
===

Command Line Interface
======================

.. click:: mitoviz.cli:main
    :prog: mitoviz
    :show-nested:

____

Python Module
=============

.. automodule:: mitoviz.plot_vcf
    :members:

.. automodule:: mitoviz.plot_df
    :members:

.. automodule:: mitoviz.plot_table
    :members:
